# Security Policy

## Supported Versions

Versions with ":white_check_mark:" are actively maintained and receiving updates.
Versions with ":x:" are outdated and should not be used over the remake.

| Version | Supported          |
| ------- | ------------------ |
| > 4.0 (REMAKE)   | :white_check_mark: |
| < 4.0 (OLD)   | :x:                |
